@@ -11,5 +11,6 @@ class DeviceOfflineError(Exception):
 class HttpRequestError(HTTPError):
     """Class for requests errors"""
 
-    def __init__(self, *args):
+    def __init__(self, *args, status_code):
         super().__init__(args)
+        self.status_code = status_code
